@@ -1,9 +1,9 @@
 """Top-level package for lognflow."""
 
-__author__ = """Alireza Sadri"""
+__author__ = 'Alireza Sadri'
 __email__ = 'arsadri@gmail.com'
-__version__ = '0.1.0'
+__version__ = '0.7.4'
 
-from .lognflow import lognflow, select_directory
+from .lognflow import lognflow, select_directory, select_file
 from .logviewer import logviewer
 from .printprogress import printprogress
\ No newline at end of file
