@@ -26,16 +26,34 @@ def test_content(response):
     # from bs4 import BeautifulSoup
     # assert 'GitHub' in BeautifulSoup(response.content).title.string
 
-def test_lognflow():
+def test_lognflow_conflict_in_names():
     logger = lognflow(temp_dir)
-    logger('This is a test for lognflow and log_var')    
-    for _ in range(10000):
-        logger(f'Log{_}'*200)
+    logger('This is a test for conflict in names')
+    logger1 = lognflow(logger.log_dir)
+    logger2 = lognflow(logger.log_dir)
+    print(logger1.log_dir)
+    print(logger2.log_dir)
+
+def test_log_text():
+    logger = lognflow(temp_dir)
+    logger('This is a test for log_text')    
+    for _ in range(1000000):
+        logger(f'{_}')
 
     logger.log_text('not_main_script',
            'This is a new log file for another script')
     logger.log_text('not_main_script',
                     'For other log files you need to mention the log_name')
+    logger.log_text('not_main_script3',
+           'This is a new log file for another script')
+    logger.log_text('not_main_script4',
+                    'For other log files you need to mention the log_name')
+    logger.log_text('not_main_script',
+           'This is a new log file for another script')
+    logger.log_text('not_main_script',
+                    'For other log files you need to mention the log_name')
+    for _ in range(1000000):
+        logger(f'{_}')
 
 def test_logger():
     ''' test the logger call funciton
@@ -54,13 +72,13 @@ def test_logger():
     c = 'asdf'
     
     logger(a)
-    logger('a', a)
-    logger('aa', a, save_as = 'txt', time_in_file_name = False)
+    logger.log_single('a', a)
+    logger.log_single('aa', a, save_as = 'txt', time_tag = False)
     logger(b)
-    logger('b', b)
-    logger('bb', b, save_as = 'txt', time_in_file_name = False)
+    logger.log_single('b', b)
+    logger.log_single('bb', b, save_as = 'txt', time_tag = False)
     logger(c)
-    logger('test/c', c, save_as = 'txt')
+    logger.log_single('test/c', c, save_as = 'txt')
 
 def test_log_flush_period():
     logger = lognflow(temp_dir, log_flush_period = 30)
@@ -71,7 +89,7 @@ def test_log_flush_period():
         while(time.time() < time_time + 10):
             pass
         time_time = time.time()
-        logger(f'Log{_}'*200)
+        logger(f'Log{_}'*20)
         
 
     logger.log_text('not_main_script',
@@ -93,28 +111,23 @@ def test_log_var_without_time_stamp():
 
     for _ in range(10):
         logger.log_single('vars/vec/v', np.random.rand(10000), 
-                       time_in_file_name = False)
+                       time_tag = False)
         
 def test_log_animation():
     var1 = np.random.rand(32, 100, 100)
     logger = lognflow(temp_dir)
     logger('This is a test for log_animation')    
-    
     logger.log_animation('var1',var1)
 
 def test_log_single():
     var1 = np.random.rand(100)
     
     logger = lognflow(temp_dir)
-    logger('This is a test for log_plot')    
-    
+    logger('This is a test for log_single')    
     logger.log_single('var1',var1)
-    
     a_dict = dict({'str_var': 'This is a string',
                    'var1': var1})
-    
     logger.log_single('a_dict', a_dict)
-    
     logger.log_single('a_dict', a_dict, save_as = 'txt')
 
 def test_log_plot():
@@ -179,7 +192,16 @@ def test_log_imshow():
     logger('This is a test for log_imshow')    
     logger.log_imshow('var3d', np.random.rand(100, 100))    
 
+def test_log_surface():
+    logger = lognflow(temp_dir)
+    logger('This is a test for log_surface')    
+    logger.log_surface('var3d', np.random.rand(100, 100))    
+
 def test_prepare_stack_of_images():
+    """ 
+        When we have 8 set of images, each is 100x100 and there are 9 of them 
+        which will appear as 3x3 tile.
+    """
     stack_1 = np.random.rand(8, 100, 100, 9)
     stack_1[:, :1, :, :] = np.nan
     stack_1[:, :, :1, :] = np.nan
@@ -242,22 +264,38 @@ def test_rename():
     logger.rename(logger.log_dir.name + '_new_name')
     logger('This is another test for test_rename')
     
+def test_log_single_text():
+    logger = lognflow(temp_dir)
+    logger('This is a test for test_log_single_text', flush = True)
+    var = 2
+    logger.log_single('text_log', 'hello\n', save_as='txt', time_tag = False)
+    logger.log_single('text_log', 'bye\n', save_as='txt', time_tag = False)
+    logger.log_single('text_log', var, save_as='txt', time_tag = False)
+    
 if __name__ == '__main__':
+    
+    #-----IF RUN BY PYTHON------#
     temp_dir = select_directory()
+    #---------------------------#
+    
+    test_log_text()
+    exit()
+    test_log_single_text()
+    test_log_surface()
+    test_log_single()
+    test_lognflow_conflict_in_names()
+    test_rename()
     test_log_plot()
     test_prepare_stack_of_images()
     test_logger()
     test_log_flush_period()
     test_log_var_without_time_stamp()
-    test_lognflow()
     test_log_var()
     test_log_animation()
-    test_log_single()
     test_log_hist()
     test_log_scatter3()
     test_log_plt()
     test_log_hexbin()
     test_log_imshow()
     test_log_canvas()
-    test_log_confusion_matrix()
-    test_rename()
\ No newline at end of file
+    test_log_confusion_matrix()
\ No newline at end of file
